package Bundle::TreeDumper ;

our $VERSION = '0.13';

1;

__END__

=head1 NAME

Bundle::TreeDumper - Installs all Data::TreeDumper modules.

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Bundle::TreeDumper'>

=head1 DESCRIPTION

This bundle installs all the modules in the Data::TreeDumper family. see the cpan FAQ for more
information about bundles.

=head1 CONTENTS

Data::TreeDumper 0.23,
Data::TreeDumper::OO 0.06,
Data::TreeDumper::Renderer::ASCII 0.03,
Data::TreeDumper::Renderer::DHTML 0.05,
Data::TreeDumper::Renderer::GTK 0.01,

=head1 LICENSE

Same licence as Perl.

=head1 AUTHOR

KHEMIR Nadim <nadim@khemir.net>

=head1 SEE ALSO

L<perl>.

=cut
